ds_standard_features library

Classes

Abortable
An HTTP request that can be aborted before it completes.
AbortableMultipartRequest
A MultipartRequest which supports abortion using abortTrigger.
AbortableRequest
A Request which supports abortion using abortTrigger.
AbortableStreamedRequest
A StreamedRequest which supports abortion using abortTrigger.
AccumulatorSink<T>
A sink that provides access to all the events that have been passed to it.
Arena
An Allocator which frees all allocations at the same time.
ArgParser
A class for taking a list of raw command line arguments and parsing out options and flags from them.
ArgResults
The results of parsing a series of command line arguments using ArgParser.parse.
AsyncCache<T>
Runs asynchronous functions and caches the result for a period of time.
AsyncMemoizer<T>
A class for running an asynchronous function exactly once and caching its result.
AuthenticationChallenge
A single challenge in a WWW-Authenticate header, parsed as per RFC 2617.
BaseClient
The abstract base class for an HTTP client.
BaseRequest
The base class for HTTP requests.
BaseResponse
The base class for HTTP responses.
BaseResponseWithUrl
A BaseResponse with a url field.
Bidi
This provides utility methods for working with bidirectional text. All of the methods are static, and are organized into a class primarily to group them together for documentation and discoverability.
BidiFormatter
Bidi stands for Bi-directional text. According to Wikipedia: Bi-directional text is text containing text in both text directionalities, both right-to-left (RTL) and left-to-right (LTR). It generally involves text containing different types of alphabets, but may also refer to boustrophedon, which is changing text directionality in each row.
BoolList
A space-efficient list of boolean values.
ByteAccumulatorSink
A sink that provides access to the concatenated bytes passed to it.
ByteStream
A stream of chunks of bytes representing a single piece of data.
CallocAllocator
Manages memory on the native heap.
CancelableCompleter<T>
A completer for a CancelableOperation.
CancelableOperation<T>
An asynchronous operation that can be cancelled.
CanonicalizedMap<C, K, V>
A map whose keys are converted to canonical values of type C.
CaseInsensitiveEquality
String equality that's insensitive to differences in ASCII case.
CaseInsensitiveMap<V>
A map from case-insensitive strings to values.
CharacterRange
A range of characters of a Characters.
Characters
The characters of a string.
ChunkedCodingCodec
A codec that encodes and decodes the chunked transfer coding.
ChunkedCodingDecoder
A converter that decodes byte arrays into chunks with size tags.
ChunkedCodingEncoder
A converter that encodes byte arrays into chunks with size tags.
ChunkedStreamReader<T>
Utility class for reading elements from a chunked stream.
Client
The interface for HTTP clients that take care of maintaining persistent connections across multiple requests to the same server.
ClientSettings
Settings for a TransportConnection a client can make.
ClientTransportConnection
ClientTransportStream
CodePage
A mapping between bytes and characters.
CodePageDecoder
A code page decoder, converts from bytes to characters.
CodePageEncoder
Encoder for a code page.
CombinedIterableView<T>
A view of several iterables combined sequentially into a single iterable.
CombinedListView<T>
A view of several lists combined into a single list.
CombinedMapView<K, V>
Returns a new map that represents maps flattened into a single map.
DataStreamMessage
Represents a data message which can be sent over a HTTP/2 stream.
DateFormat
DateFormat is for formatting and parsing dates in a locale-sensitive manner.
DeepCollectionEquality
Deep equality on collections.
DefaultEquality<E>
Equality of objects that compares only the natural equality of the objects.
DelegatingEventSink<T>
Simple delegating wrapper around an EventSink.
DelegatingFuture<T>
A wrapper that forwards calls to a Future.
DelegatingIterable<E>
An Iterable that delegates all operations to a base iterable.
DelegatingList<E>
A List that delegates all operations to a base list.
DelegatingMap<K, V>
A Map that delegates all operations to a base map.
DelegatingQueue<E>
A Queue that delegates all operations to a base queue.
DelegatingSet<E>
A Set that delegates all operations to a base set.
DelegatingSink<T>
Simple delegating wrapper around a Sink.
DelegatingStream<T>
Simple delegating wrapper around a Stream.
DelegatingStreamConsumer<T>
Simple delegating wrapper around a StreamConsumer.
DelegatingStreamSink<T>
Simple delegating wrapper around a StreamSink.
DelegatingStreamSubscription<T>
Simple delegating wrapper around a StreamSubscription.
Digest
A message digest as computed by a Hash or HMAC function.
Equality<E>
A generic equality relation on objects.
EqualityBy<E, F>
Equality of objects based on derived values.
EqualityMap<K, V>
A Map whose key equality is determined by an Equality object.
EqualitySet<E>
A Set whose key equality is determined by an Equality object.
ErrorCode
ErrorResult
A result representing a thrown error.
EventSinkBase<T>
An abstract class that implements EventSink in terms of onAdd, onError, and onClose methods.
FakeAsync
A class that mocks out the passage of time within a Zone.
FakePlatform
Provides a mutable implementation of the Platform interface.
FakeTimer
An implementation of Timer that's controlled by a FakeAsync.
FixedDateTimeFormatter
A formatter and parser for DateTime in a fixed format String pattern.
Float32Buffer
Float32Queue
A QueueList that efficiently stores IEEE 754 single-precision binary floating-point numbers.
Float32x4Buffer
Float32x4Queue
A QueueList that efficiently stores Float32x4 numbers.
Float64Buffer
Float64Queue
A QueueList that efficiently stores IEEE 754 double-precision binary floating-point numbers.
FutureGroup<T>
A collection of futures waits until all added Futures complete.
Hash
An interface for cryptographic hash functions.
A HTTP/2 header.
HeadersStreamMessage
Represents a headers message which can be sent over a HTTP/2 stream.
HeapPriorityQueue<E>
Heap based priority queue.
HexCodec
A codec that converts byte arrays to and from hexadecimal strings, following the Base16 spec.
HexDecoder
A converter that decodes hexadecimal strings into byte arrays.
HexEncoder
A converter that encodes byte arrays into hexadecimal strings.
Hmac
An implementation of keyed-hash method authentication codes.
IdentityCodec<T>
A Codec that performs the identity conversion (changing nothing) in both directions.
IdentityEquality<E>
Equality of objects that compares only the identity of the objects.
Immutable
Annotation on an immutable class.
Int16Buffer
Int16Queue
A QueueList that efficiently stores 16-bit signed integers.
Int32
An immutable 32-bit signed integer, in the range -2^31, 2^31 - 1. Arithmetic operations may overflow in order to maintain this range.
Int32Buffer
Int32Queue
A QueueList that efficiently stores 32-bit signed integers.
Int32x4Buffer
Int32x4Queue
A QueueList that efficiently stores Int32x4 numbers.
Int64
An immutable 64-bit signed integer, in the range -2^63, 2^63 - 1. Arithmetic operations may overflow in order to maintain this range.
Int64Buffer
Int64Queue
A QueueList that efficiently stores 64-bit signed integers.
Int8Buffer
Int8Queue
A QueueList that efficiently stores 8-bit signed integers.
Intl
The Intl class provides a common entry point for internationalization related tasks. An Intl instance can be created for a particular locale and used to create a date format via anIntl.date(). Static methods on this class are also used in message formatting.
IntX
A fixed-precision integer.
IOSinkBase
An abstract class that implements dart:io's IOSink's API in terms of onAdd, onError, onClose, and onFlush methods.
IterableEquality<E>
Equality on iterables.
IterableZip<T>
Iterable that iterates over lists of values from other iterables.
LazyStream<T>
A Stream wrapper that forwards to another Stream that's initialized lazily.
Level
Levels to control logging output. Logging can be enabled to include all levels above certain Level. Levels are ordered using an integer value Level.value. The predefined Level constants below are sorted as follows (in descending order): Level.SHOUT, Level.SEVERE, Level.WARNING, Level.INFO, Level.CONFIG, Level.FINE, Level.FINER, Level.FINEST, and Level.ALL.
ListEquality<E>
Equality on lists.
ListSlice<E>
A list view of a range of another list.
LocalPlatform
Platform implementation that delegates directly to dart:io.
Logger
Use a Logger to log debug messages.
LogRecord
A log entry representation used to propagate information from Logger to individual handlers.
MallocAllocator
Manages memory on the native heap.
MapEquality<K, V>
Equality on maps.
MapKeySet<E>
An unmodifiable Set view of the keys of a Map.
MapValueSet<K, V>
Creates a modifiable Set view of the values of a Map.
MediaType
A class representing an HTTP media type, as used in Accept and Content-Type headers.
MicroMoney
Used primarily for currency formatting, this number-like class stores millionths of a currency unit, typically as an Int64.
MultiEquality<E>
Combines several equalities into a single equality.
MultipartFile
A file to be uploaded as part of a MultipartRequest.
MultipartRequest
A multipart/form-data request.
NonGrowableListMixin<E>
Mixin class that implements a throwing version of all list operations that change the List's length.
NonGrowableListView<E>
A fixed-length list.
NullStreamSink<T>
A StreamSink that discards all events.
NumberFormat
Provides the ability to format a number in a locale-specific way.
NumberParserBase<R>
Option
A command-line option.
OptionType
What kinds of values an option accepts.
PercentCodec
A codec that converts byte arrays to and from percent-encoded (also known as URL-encoded) strings according to RFC 3986.
PercentDecoder
A converter that decodes percent-encoded strings into byte arrays.
PercentEncoder
A converter that encodes byte arrays into percent-encoded strings.
Platform
Provides API parity with the Platform class in dart:io, but using instance properties rather than static properties. This difference enables the use of these APIs in tests, where you can provide mock implementations.
PriorityQueue<E>
A priority queue is a priority based work-list of elements.
QueueList<E>
A class that efficiently implements both Queue and List.
RecordUse
Annotation on static method or class whose accesses will be recorded.
Request
An HTTP request where the entire request body is known in advance.
Required
Annotation on a required named parameter.
Response
An HTTP response where the entire response body is known in advance.
RestartableTimer
A non-periodic timer that can be restarted any number of times.
Result<T>
The result of a computation.
ResultFuture<T>
A Future wrapper that provides synchronous access to the result of the wrapped Future once it's completed.
ServerSettings
Settings for a TransportConnection a server can make.
ServerTransportConnection
ServerTransportStream
SetEquality<E>
Equality of sets.
Settings
Settings for a TransportConnection.
SingleSubscriptionTransformer<S, T>
A transformer that converts a broadcast stream into a single-subscription stream.
StreamCloser<T>
A StreamTransformer that allows the caller to forcibly close the transformed Stream.
StreamCompleter<T>
A single-subscription stream where the contents are provided later.
StreamedRequest
An HTTP request where the request body is sent asynchronously after the connection has been established and the headers have been sent.
StreamedResponse
An HTTP response where the response body is received asynchronously after the headers have been received.
StreamGroup<T>
A collection of streams whose events are unified and sent through a central stream.
StreamMessage
Represents a message which can be sent over a HTTP/2 stream.
StreamQueue<T>
An asynchronous pull-based interface for accessing stream events.
StreamQueueTransaction<T>
A transaction on a StreamQueue, created by StreamQueue.startTransaction.
StreamSinkBase<T>
An abstract class that implements StreamSink in terms of onAdd, onError, and onClose methods.
StreamSinkCompleter<T>
A sink where the destination is provided later.
StreamSinkTransformer<S, T>
A StreamSinkTransformer transforms the events being passed to a sink.
StreamSplitter<T>
A class that splits a single source stream into an arbitrary number of (single-subscription) streams (called "branch") that emit the same events.
StreamZip<T>
A stream that combines the values of other streams.
StringAccumulatorSink
A sink that provides access to the concatenated strings passed to it.
SubscriptionStream<T>
A Stream adapter for a StreamSubscription.
TextDirection
Represents directionality of text.
TransportConnection
Represents a HTTP/2 connection.
TransportStream
Represents a HTTP/2 stream.
TransportStreamPush
Represents a remote stream push.
Uint16Buffer
Uint16Queue
A QueueList that efficiently stores 16-bit unsigned integers.
Uint32Buffer
Uint32Queue
A QueueList that efficiently stores 32-bit unsigned integers.
Uint64Buffer
Uint64Queue
A QueueList that efficiently stores 64-bit unsigned integers.
Uint8Buffer
Uint8ClampedBuffer
Uint8ClampedQueue
A QueueList that efficiently stores 8-bit unsigned integers.
Uint8Queue
A QueueList that efficiently stores 8-bit unsigned integers.
UnionSet<E>
A single set that provides a view of the union over a set of sets.
UnionSetController<E>
A controller that exposes a view of the union of a collection of sets.
UnmodifiableListView<E>
An unmodifiable List view of another List.
UnmodifiableMapMixin<K, V>
Mixin class that implements a throwing version of all map operations that change the Map.
UnmodifiableMapView<K, V>
View of a Map that disallow modifying the map.
UnmodifiableSetMixin<E>
Mixin class that implements a throwing version of all set operations that change the Set.
UnmodifiableSetView<E>
An unmodifiable set.
UnorderedIterableEquality<E>
Equality of the elements of two iterables without considering order.
UseResult
Annotation on function or property whose value must not be ignored.
Utf16
The contents of a native zero-terminated array of UTF-16 code units.
Utf8
The contents of a native zero-terminated array of UTF-8 code units.
ValueResult<T>
A result representing a returned value.

Extensions

ChunkedStreamReaderByteStreamExt on ChunkedStreamReader<int>
Extensions for using ChunkedStreamReader with byte-streams.
ComparatorExtension on Comparator<T>
Extensions on comparator functions.
HeadersWithSplitValues on BaseResponse
IterableComparableExtension on Iterable<T>
Extensions that apply to iterables of Comparable elements.
IterableDoubleExtension on Iterable<double>
Extension on iterables of double.
IterableExtension on Iterable<T>
Extensions that apply to all iterables.
IterableIntegerExtension on Iterable<int>
Extension on iterables of integers.
IterableIterableExtension on Iterable<Iterable<T>>
Extensions on iterables whose elements are also iterables.
IterableNullableExtension on Iterable<T?>
Extensions that apply to iterables with a nullable element type.
IterableNumberExtension on Iterable<num>
Extensions that apply to iterables of numbers.
ListComparableExtensions on List<E>
Various extensions on lists of comparable elements.
ListExtensions on List<E>
Various extensions on lists of arbitrary elements.
StreamExtensions on Stream<T>
Utility extensions on Stream.
StreamSinkExtensions on StreamSink<T>
Extensions on StreamSink to make stream transformations more fluent.
StringCharacters on String
StringUtf16Pointer on String
Extension method for converting a String to a Pointer<Utf16>.
StringUtf8Pointer on String
Extension method for converting a String to a Pointer<Utf8>.
Utf16Pointer on Pointer<Utf16>
Extension method for converting aPointer<Utf16> to a String.
Utf8Pointer on Pointer<Utf8>
Extension method for converting a Pointer<Utf8> to a String.

Constants

alwaysThrows → const Object
Annotation marking a function as always throwing.
awaitNotRequired → const Object
Annotation on asynchronous function whose Future can be ignored.
calloc → const CallocAllocator
Manages memory on the native heap.
checked → const Object
Annotation that no longer has any effect.
chunkedCoding → const ChunkedCodingCodec
The canonical instance of ChunkedCodingCodec.
defaultLevel → const Level
The default Level.
doNotStore → const Object
Annotation on function or property whose value must not be stored.
doNotSubmit → const Object
Annotation marking declaration that should be removed before publishing.
experimental → const Object
Annotation marking declaration as experimental and subject to change.
factory → const Object
Annotation on a function that creates new objects.
hex → const HexCodec
The canonical instance of HexCodec.
immutable → const Immutable
Annotation on an immutable class.
internal → const Object
Annotation on declaration that should not be used outside of its package.
isTest → const Object
Annotation on a test framework function that introduces a single test.
isTestGroup → const Object
Annotation on a test framework function that introduces a group of tests.
literal → const Object
Annotation on constructor that must be invoked with const if possible.
malloc → const MallocAllocator
Manages memory on the native heap.
md5 → const Hash
An implementation of the MD5 hash function.
mustBeConst → const Object
Annotation on a parameter whose arguments must be constants.
mustBeOverridden → const Object
Annotation on instance members that must be overridden by subclasses.
mustCallSuper → const Object
Annotation on instance member that overriding members must call.
nonVirtual → const Object
Annotation on instance member that must not be overridden.
optionalTypeArgs → const Object
Annotation on type arguments that can safely be omitted.
percent → const PercentCodec
The canonical instance of PercentCodec.
protected → const Object
Annotation on instance member that should only be used by subclasses.
redeclare → const Object
Annotation on extension type members which redeclare superinterface members.
reopen → const Object
Annotation on declaration with less access restrictions than superinterface.
required → const Required
Annotation on named parameter that should always have an argument supplied.
sealed → const Object
Annotation on class that must not be subclassed outside of its package.
sha1 → const Hash
An implementation of the SHA-1 hash function.
sha224 → const Hash
An implementation of the SHA-224 hash function.
sha256 → const Hash
An implementation of the SHA-256 hash function.
sha384 → const Hash
An implementation of the SHA-384 hash function.
sha512 → const Hash
An implementation of the SHA-512 hash function.
sha512224 → const Hash
An implementation of the SHA-512/224 hash function.
sha512256 → const Hash
An implementation of the SHA-512/256 hash function.
useResult → const UseResult
Annotation on function or property whose value must not be ignored.
virtual → const Object
Annotation which no longer has any effect.
visibleForOverriding → const Object
Annotation on declaration that should not be used outside of its package.
visibleForTesting → const Object
Annotation on a public declaration that should only be used in tests.

Properties

hierarchicalLoggingEnabled bool
Whether to allow fine-grain logging and configuration of loggers in a hierarchy.
getter/setter pair
isAndroid bool
Whether the current operating system is a version of Android.
no setter
isBrowser bool
Whether running in a web browser.
no setter
isFuchsia bool
Whether the current operating system is a version of Fuchsia.
no setter
isIOS bool
Whether the current operating system is a version of iOS.
no setter
isLinux bool
Whether the current operating system is a version of Linux.
no setter
isMacOS bool
Whether the current operating system is a version of macOS.
no setter
isWindows bool
Whether the current operating system is a version of Microsoft Windows.
no setter
latin10 CodePage
The ISO-8859-16/Latin-10 (South Eastern European) code page.
final
latin2 CodePage
The ISO-8859-2/Latin-2 (Eastern European) code page.
final
latin3 CodePage
The ISO-8859-3/Latin-3 (South European) code page.
final
latin4 CodePage
The ISO-8859-4/Latin-4 (North European) code page.
final
latin5 CodePage
The ISO-8859-9/Latin-5 (Turkish) code page.
final
latin6 CodePage
The ISO-8859-10/Latin-6 (Nordic) code page.
final
latin7 CodePage
The ISO-8859-13/Latin-6 (Baltic Rim) code page.
final
latin8 CodePage
The ISO-8859-14/Latin-8 (Celtic) code page.
final
latin9 CodePage
The ISO-8859-15/Latin-9 (Western European revised) code page.
final
latinArabic CodePage
The ISO-8859-6/Latin-Arabic code page.
final
latinCyrillic CodePage
The ISO-8859-5/Latin-Cyrillic code page.
final
latinGreek CodePage
The ISO-8859-7/Latin-Greek code page.
final
latinHebrew CodePage
The ISO-8859-7/Latin-Hebrew code page.
final
latinThai CodePage
The ISO-8859-11/Latin-Thai code page.
final
operatingSystem String
Identification of the current operating system or platform.
no setter
operatingSystemVersion String
Representation of the version of the current operating system or platform.
no setter
recordStackTraceAtLevel Level
Automatically record stack traces for any message of this level or above.
getter/setter pair
zoneArena Arena
A zone-specific Arena.
no setter

Functions

binarySearch<E>(List<E> sortedList, E value, {int compare(E, E)?}) int
Returns a position of the value in sortedList, if it is there.
collectBytes(Stream<List<int>> source) Future<Uint8List>
Collects an asynchronous sequence of byte lists into a single list of bytes.
collectBytesCancelable(Stream<List<int>> source) CancelableOperation<Uint8List>
Collects an asynchronous sequence of byte lists into a single list of bytes.
compareAsciiLowerCase(String a, String b) int
Compares a and b lexically, converting ASCII letters to lower case.
compareAsciiLowerCaseNatural(String a, String b) int
Compares strings a and b according to lower-case natural sort ordering.
compareAsciiUpperCase(String a, String b) int
Compares a and b lexically, converting ASCII letters to upper case.
compareAsciiUpperCaseNatural(String a, String b) int
Compares strings a and b according to upper-case natural sort ordering.
compareNatural(String a, String b) int
Compares strings a and b according to natural sort ordering.
delete(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding}) Future<Response>
Sends an HTTP DELETE request with the given headers to the given URL.
equalsIgnoreAsciiCase(String a, String b) bool
Checks if strings a and b differ only on the case of ASCII letters.
fakeAsync<T>(T callback(FakeAsync async), {DateTime? initialTime}) → T
Runs callback in a Zone where all asynchrony is controlled by an instance of FakeAsync.
formatHttpDate(DateTime date) String
Return a HTTP-formatted string representation of date.
get(Uri url, {Map<String, String>? headers}) Future<Response>
Sends an HTTP GET request with the given headers to the given URL.
groupBy<S, T>(Iterable<S> values, T key(S)) Map<T, List<S>>
Groups the elements in values by the value returned by key.
hashIgnoreAsciiCase(String string) int
Hash code for a string which is compatible with equalsIgnoreAsciiCase.
Sends an HTTP HEAD request with the given headers to the given URL.
insertionSort<E>(List<E> elements, {int compare(E, E)?, int start = 0, int? end}) → void
Sort a list between start (inclusive) and end (exclusive) using insertion sort.
lastBy<S, T>(Iterable<S> values, T key(S)) Map<T, S>
Associates the elements in values by the value returned by key.
lowerBound<E>(List<E> sortedList, E value, {int compare(E, E)?}) int
Returns the first position in sortedList that does not compare less than value.
mapMap<K1, V1, K2, V2>(Map<K1, V1> map, {K2 key(K1, V1)?, V2 value(K1, V1)?}) Map<K2, V2>
Creates a new map from map with new keys and values.
maxBy<S, T>(Iterable<S> values, T orderBy(S), {int compare(T, T)?}) → S?
Returns the element of values for which orderBy returns the maximum value.
mergeMaps<K, V>(Map<K, V> map1, Map<K, V> map2, {V value(V, V)?}) Map<K, V>
Returns a new map with all key/value pairs in both map1 and map2.
mergeSort<E>(List<E> elements, {int start = 0, int? end, int compare(E, E)?}) → void
Sorts a list between start (inclusive) and end (exclusive) using the merge sort algorithm.
minBy<S, T>(Iterable<S> values, T orderBy(S), {int compare(T, T)?}) → S?
Returns the element of values for which orderBy returns the minimum value.
parseHttpDate(String date) DateTime
Parses an HTTP-formatted date into a UTC DateTime.
patch(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding}) Future<Response>
Sends an HTTP PATCH request with the given headers and body to the given URL.
post(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding}) Future<Response>
Sends an HTTP POST request with the given headers and body to the given URL.
put(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding}) Future<Response>
Sends an HTTP PUT request with the given headers and body to the given URL.
read(Uri url, {Map<String, String>? headers}) Future<String>
Sends an HTTP GET request with the given headers to the given URL and returns a Future that completes to the body of the response as a String.
readBytes(Uri url, {Map<String, String>? headers}) Future<Uint8List>
Sends an HTTP GET request with the given headers to the given URL and returns a Future that completes to the body of the response as a list of bytes.
reverse<E>(List<E> elements, [int start = 0, int? end]) → void
Reverses a list, or a part of a list, in-place.
runWithClient<R>(R body(), Client clientFactory(), {ZoneSpecification? zoneSpecification}) → R
Runs body in its own Zone with the Client returned by clientFactory set as the default Client.
shuffle(List elements, [int start = 0, int? end, Random? random]) → void
Shuffles a list randomly.
stronglyConnectedComponents<T>(Map<T, Iterable<T>> graph) List<Set<T>>
Returns the strongly connected components of graph, in topological order.
subscriptionTransformer<T>({Future handleCancel(StreamSubscription<T>)?, void handlePause(StreamSubscription<T>)?, void handleResume(StreamSubscription<T>)?}) StreamTransformer<T, T>
Creates a StreamTransformer that modifies the behavior of subscriptions to a stream.
toBeginningOfSentenceCase<T extends String?>(T input, [String? locale]) → T
Convert a string to beginning of sentence case, in a way appropriate to the locale.
transitiveClosure<T>(Map<T, Iterable<T>> graph) Map<T, Set<T>>
Returns the transitive closure of graph.
typedStreamTransformer<S, T>(StreamTransformer transformer) StreamTransformer<S, T>
Creates a wrapper that coerces the type of transformer.
using<R>(R computation(Arena arena), [Allocator wrappedAllocator = calloc]) → R
Runs computation with a new Arena, and releases all allocations at the end.
withZoneArena<R>(R computation(), [Allocator wrappedAllocator = calloc]) → R
Creates a zoned Arena to manage native resources.

Typedefs

ActiveStateHandler = void Function(bool isActive)

Exceptions / Errors

ArgParserException
An exception thrown by ArgParser.
ClientException
An exception caused by an error in a pkg/http client.
RequestAbortedException
Thrown when an HTTP request is aborted.
StreamTransportException
An exception thrown when a HTTP/2 stream error occured.
TransportConnectionException
An exception thrown when a HTTP/2 connection error occurred.
TransportException
An exception thrown by the HTTP/2 implementation.